'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.switchPluginPath = exports.reactClass = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

// Import selectors defined in poi


var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactRedux = require('react-redux');

var _reselect = require('reselect');

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _path = require('path');

var _reactBootstrap = require('react-bootstrap');

var _selectors = require('views/utils/selectors');

var _functions = require('./parts/functions');

var _fleetList = require('./parts/fleet-list');

var _fleetList2 = _interopRequireDefault(_fleetList);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const { i18n, getStore } = window;
const __ = i18n['poi-plugin-anchorage-repair'].__.bind(i18n['poi-plugin-anchorage-repair']);

const AKASHI_ID = [182, 187]; // akashi and kai ID in $ships
const SRF_ID = 86; // Ship Repair Facility ID in $slotitems


// check a fleet status, returns information related to anchorage repair
const fleetAkashiConv = (fleet, $ships, ships, equips, repairId) => {
  const pickKey = ['api_id', 'api_ship_id', 'api_lv', 'api_nowhp', 'api_maxhp', 'api_ndock_time'];

  let canRepair = false;
  let akashiFlagship = false;
  let repairCount = 0;
  const inExpedition = _lodash2.default.get(fleet, 'api_mission.0') && true;
  const flagShipInRepair = _lodash2.default.includes(repairId, _lodash2.default.get(fleet, 'api_ship.0', -1));
  const flagship = ships[_lodash2.default.get(fleet, 'api_ship.0', -1)];

  if (flagship != null) {
    akashiFlagship = _lodash2.default.includes(AKASHI_ID, flagship.api_ship_id);
    repairCount = _lodash2.default.filter(flagship.api_slot, item => _lodash2.default.get(equips, `${item}.api_slotitem_id`, -1) === SRF_ID).length;
    repairCount += akashiFlagship ? 2 : 0;
  }

  canRepair = akashiFlagship && !inExpedition && !flagShipInRepair;

  const repairDetail = _lodash2.default.map(_lodash2.default.filter(fleet.api_ship, shipId => shipId > 0), (shipId, index) => {
    if (shipId === -1) return false; // break, LODASH ONLY

    const ship = _lodash2.default.pick(ships[shipId], pickKey);

    const constShip = _lodash2.default.pick($ships[ship.api_ship_id], ['api_name', 'api_stype']);

    return _extends({}, ship, constShip, {
      estimate: (0, _functions.akashiEstimate)(ship),
      timePerHP: (0, _functions.getTimePerHP)(ship.api_lv, constShip.api_stype),
      inRepair: _lodash2.default.includes(repairId, ship.api_id),
      availableSRF: index < repairCount
    });
  });

  return {
    api_id: fleet.api_id || -1,
    shipId: fleet.api_ship || [],
    canRepair,
    akashiFlagship,
    inExpedition,
    flagShipInRepair,
    repairCount,
    repairDetail
  };
};

// selectors

const repairIdSelector = (0, _reselect.createSelector)([_selectors.repairsSelector], repair => _lodash2.default.map(repair, dock => dock.api_ship_id));

const constShipsSelector = state => state.const.$ships || {};

const fleetsAkashiSelector = (0, _reselect.createSelector)([constShipsSelector, _selectors.fleetsSelector, _selectors.shipsSelector, _selectors.equipsSelector, repairIdSelector], ($ships, fleets, ships, equips, repairId) => ({ fleets: _lodash2.default.map(fleets, fleet => fleetAkashiConv(fleet, $ships, ships, equips, repairId)) })

// React

);const reactClass = exports.reactClass = (0, _reactRedux.connect)((0, _selectors.createDeepCompareArraySelector)([fleetsAkashiSelector, _selectors.miscSelector], (data, { canNotify }) => _extends({}, data, {
  canNotify
})))(class PluginAnchorageRepair extends _react.Component {

  constructor(props) {
    super(props);

    this.handleSelectTab = key => {
      this.setState({ activeTab: key });
    };

    this.state = {
      activeTab: 1
    };
  }

  render() {
    return _react2.default.createElement(
      'div',
      { id: 'anchorage-repair' },
      _react2.default.createElement('link', { rel: 'stylesheet', href: (0, _path.join)(__dirname, 'assets', 'style.css') }),
      _react2.default.createElement(
        _reactBootstrap.Tabs,
        { activeKey: this.state.activeTab, onSelect: this.handleSelectTab, id: 'anchorage-tab' },
        _lodash2.default.map(this.props.fleets, (fleet, index) => _react2.default.createElement(
          _reactBootstrap.Tab,
          {
            eventKey: fleet.api_id,
            title: fleet.api_id,
            key: `anchorage-tab-${index}`,
            tabClassName: fleet.canRepair ? 'can-repair' : ''
          },
          _react2.default.createElement(_fleetList2.default, { fleet: fleet })
        ))
      )
    );
  }
});

const switchPluginPath = exports.switchPluginPath = [{
  path: '/kcsapi/api_port/port',
  valid: () => {
    const { fleets = [], ships = {}, equips = {}, repairs = [] } = getStore('info') || {};
    const $ships = getStore('const.$ships');
    const repairId = repairs.map(dock => dock.api_ship_id);

    const result = fleets.map(fleet => fleetAkashiConv(fleet, $ships, ships, equips, repairId));
    return result.some(fleet => fleet.canRepair && fleet.repairDetail.some(ship => ship.estimate > 0));
  }
}];